@@ -22,8 +22,8 @@
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
 
-#ifndef _PTH_CONF_H
-#define _PTH_CONF_H
+#ifndef _PTH_CONF_H_
+#define _PTH_CONF_H_
 
 /* a little wrapper for sigsetjmp() to help the Autoconf stuff */
 #define sigsetjmp1(jp) sigsetjmp(jp, 1)
@@ -36,6 +36,7 @@
 #undef HAVE_STACK_T
 #undef HAVE_SIZE_T
 #undef HAVE_SSIZE_T
+#undef HAVE_OFF_T
 #undef HAVE_GETTIMEOFDAY_ARGS1
 #undef HAVE_SYS_READ
 #undef HAVE_POLLIN
@@ -51,5 +52,5 @@
 
 @BOTTOM@
 
-#endif /* _PTH_CONF_H */
+#endif /* _PTH_CONF_H_ */
 
