@@ -266,7 +266,7 @@ intern int pth_mctx_set(
     if (sigaltstack(&ss, NULL) < 0)
         return FALSE;
 #elif defined(HAVE_SIGSTACK)
-    ss.ss_sp = (PTH_STACKSGROWDOWN ? stack_hi_addr : stack_lo_addr);
+    ss.ss_sp = (PTH_STACKSGROWDOWN ? sk_addr_hi : sk_addr_lo);
     ss.ss_onstack = 0;
     if (sigstack(&ss, NULL) < 0)
         return FALSE;
