@@ -37,7 +37,9 @@
 #undef PTHREAD_H
 
 /* now include our own pthread header */
+#define _PTHREAD_PRIVATE
 #include "pthread.h"
+#undef _PTHREAD_PRIVATE
 
 /*
 **  HEADER STUFF
@@ -284,7 +286,7 @@ int pthread_create(
     if (attr != NULL)
         na = (pth_attr_t)(*attr);
     else
-        na = PTH_ATTR_NULL;
+        na = PTH_ATTR_DEFAULT;
     *thread = (pthread_t)pth_spawn(na, start_routine, arg);
     if (*thread == NULL)
         return_errno(EAGAIN, EAGAIN);
@@ -962,7 +964,12 @@ int pthread_cond_timedwait(pthread_cond_t *cond, pthread_mutex_t *mutex,
         if (pthread_mutex_init(mutex, NULL) != OK)
             return errno;
     ev = pth_event(PTH_EVENT_TIME|PTH_MODE_STATIC, &ev_key, 
-                   pth_time(abstime->tv_sec, (abstime->tv_nsec)/1000));
+#ifdef __amigaos__
+                   pth_time(abstime->ts_sec, (abstime->ts_nsec)/1000)
+#else
+                   pth_time(abstime->tv_sec, (abstime->tv_nsec)/1000)
+#endif
+    );
     if (!pth_cond_await((pth_cond_t *)(*cond), (pth_mutex_t *)(*mutex), ev))
         return errno;
     return OK;
